summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/kernel/tqurl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/kernel/tqurl.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqurl.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqurl.cpp b/experimental/tqtinterface/qt4/src/kernel/tqurl.cpp
index a355c4a8f..81f8ca4c1 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqurl.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqurl.cpp
@@ -224,8 +224,8 @@ TQUrl::TQUrl( const TQUrl& url )
bool TQUrl::isRelativeUrl( const TQString &url )
{
- int colon = url.tqfind( ":" );
- int slash = url.tqfind( "/" );
+ int colon = url.find( ":" );
+ int slash = url.find( "/" );
return ( slash != 0 && ( colon == -1 || ( slash != -1 && colon > slash ) ) );
}
@@ -258,8 +258,8 @@ bool TQUrl::isRelativeUrl( const TQString &url )
Normally it is expected that the path of \a url points to a
directory, even if the path has no slash at the end. But if you
want the constructor to handle the last part of the path as a file
- name if there is no slash at the end, and to let it be tqreplaced by
- the file name of \a relUrl (if it tqcontains one), set \a checkSlash
+ name if there is no slash at the end, and to let it be replaced by
+ the file name of \a relUrl (if it contains one), set \a checkSlash
to TRUE.
*/
@@ -375,7 +375,7 @@ void TQUrl::setUser( const TQString& user )
}
/*!
- Returns TRUE if the URL tqcontains a username; otherwise returns
+ Returns TRUE if the URL contains a username; otherwise returns
FALSE.
\sa setUser() setPassword()
@@ -415,7 +415,7 @@ void TQUrl::setPassword( const TQString& pass )
}
/*!
- Returns TRUE if the URL tqcontains a password; otherwise returns
+ Returns TRUE if the URL contains a password; otherwise returns
FALSE.
\warning Passwords passed in URLs are normally \e insecure; this
@@ -454,7 +454,7 @@ void TQUrl::setHost( const TQString& host )
}
/*!
- Returns TRUE if the URL tqcontains a hostname; otherwise returns
+ Returns TRUE if the URL contains a hostname; otherwise returns
FALSE.
\sa setHost()
@@ -488,7 +488,7 @@ void TQUrl::setPort( int port )
}
/*!
- Returns TRUE if the URL tqcontains a port; otherwise returns FALSE.
+ Returns TRUE if the URL contains a port; otherwise returns FALSE.
\sa setPort()
*/
@@ -513,7 +513,7 @@ void TQUrl::setPath( const TQString& path )
}
/*!
- Returns TRUE if the URL tqcontains a path; otherwise returns FALSE.
+ Returns TRUE if the URL contains a path; otherwise returns FALSE.
\sa path() setPath()
*/
@@ -675,13 +675,13 @@ bool TQUrl::parse( const TQString& url )
relPath = forceRel = TRUE;
int hasNoHost = -1;
- int cs = url_.tqfind( ":/" );
- if ( cs != -1 ) // if a protocol is there, tqfind out if there is a host or directly the path after it
- hasNoHost = url_.tqfind( "///", cs );
+ int cs = url_.find( ":/" );
+ if ( cs != -1 ) // if a protocol is there, find out if there is a host or directly the path after it
+ hasNoHost = url_.find( "///", cs );
table[ 4 ][ 1 ] = User;
table[ 4 ][ 2 ] = User;
if ( cs == -1 || forceRel ) { // we have a relative file
- if ( url.tqfind( ':' ) == -1 || forceRel ) {
+ if ( url.find( ':' ) == -1 || forceRel ) {
table[ 0 ][ 1 ] = Path;
// Filenames may also begin with a digit
table[ 0 ][ 2 ] = Path;
@@ -692,12 +692,12 @@ bool TQUrl::parse( const TQString& url )
} else { // some checking
table[ 0 ][ 1 ] = Protocol;
// tqfind the part between the protocol and the path as the meaning
// of that part is dependend on some chars
++cs;
while ( url_[ cs ] == '/' )
++cs;
- int slash = url_.tqfind( "/", cs );
+ int slash = url_.find( "/", cs );
if ( slash == -1 )
slash = url_.length() - 1;
TQString tmp = url_.mid( cs, slash - cs + 1 );
@@ -705,7 +705,7 @@ bool TQUrl::parse( const TQString& url )
if ( !tmp.isEmpty() ) { // if this part exists
// look for the @ in this part
- int at = tmp.tqfind( "@" );
+ int at = tmp.find( "@" );
if ( at != -1 )
at += cs;
// we have no @, which means host[:port], so directly
@@ -928,8 +928,8 @@ bool TQUrl::operator==( const TQString& url ) const
}
/*!
- Sets the file name of the URL to \a name. If this URL tqcontains a
- fileName(), the original file name is tqreplaced by \a name.
+ Sets the file name of the URL to \a name. If this URL contains a
+ fileName(), the original file name is replaced by \a name.
See the documentation of fileName() for a more detailed discussion
of what is handled as file name and what is handled as a directory
@@ -951,7 +951,7 @@ void TQUrl::setFileName( const TQString& name )
p = "/";
} else {
p = path();
- int slash = p.tqfindRev( TQChar( '/' ) );
+ int slash = p.findRev( TQChar( '/' ) );
if ( slash == -1 ) {
p = "/";
} else if ( p[ (int)p.length() - 1 ] != '/' ) {
@@ -997,7 +997,7 @@ TQString TQUrl::encodedPathAndQuery()
void TQUrl::setEncodedPathAndQuery( const TQString& pathAndQuery )
{
d->cleanPathDirty = TRUE;
- int pos = pathAndQuery.tqfind( '?' );
+ int pos = pathAndQuery.find( '?' );
if ( pos == -1 ) {
d->path = pathAndQuery;
d->queryEncoded = "";
@@ -1158,7 +1158,7 @@ TQString TQUrl::dirPath() const
return TQString::null;
TQString s = path();
- int pos = s.tqfindRev( '/' );
+ int pos = s.findRev( '/' );
if ( pos == -1 ) {
return TQString::tqfromLatin1(".");
} else {
@@ -1195,7 +1195,7 @@ void TQUrl::encode( TQString& url )
for ( int i = 0; i < oldlen ;++i ) {
uchar inCh = (uchar)curl[ i ];
- if ( inCh >= 128 || special.tqcontains(inCh) ) {
+ if ( inCh >= 128 || special.contains(inCh) ) {
newUrl[ newlen++ ] = TQChar( '%' );
ushort c = inCh / 16;
@@ -692,12 +692,12 @@ bool TQUrl::parse( const TQString& url )
} else { // some checking
table[ 0 ][ 1 ] = Protocol;
- // tqfind the part between the protocol and the path as the meaning
+ // find the part between the protocol and the path as the meaning
// of that part is dependend on some chars